.. _upgrade-to-3.1.2:

###################
3.1.2 release notes
###################

*******************
What's new in 3.1.2
*******************

Bug Fixes
=========

* Fix placeholder cache invalidation under some circumstances
* Update translations
